@@ -12,23 +12,23 @@ under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 CONDITIONS OF ANY KIND, either express or implied. See the License for the
 specific language governing permissions and limitations under the License.
 """
-from lambdaguard.utils.arnparse import arnparse
-from lambdaguard.utils.acl import ACL
-from lambdaguard.utils.log import debug
 from lambdaguard.core.AWS import AWS
+from lambdaguard.utils.acl import ACL
+from lambdaguard.utils.arnparse import arnparse
+from lambdaguard.utils.log import debug
 
 
 class STS(AWS):
     def __init__(self, arn, profile=None, access_key_id=None, secret_access_key=None):
         super().__init__(arn, profile, access_key_id, secret_access_key)
         self.caller = self.get_caller_identity()
-        self.arn = arnparse(self.caller['Arn'])
-        self.acl = ACL(self.caller['Arn'])
+        self.arn = arnparse(self.caller["Arn"])
+        self.acl = ACL(self.caller["Arn"], profile, access_key_id, secret_access_key)
 
     def get_caller_identity(self):
-        '''
+        """
         Fetches STS Caller Identity
-        '''
+        """
         try:
             return self.client.get_caller_identity()
         except Exception:
