@@ -13,8 +13,8 @@ CONDITIONS OF ANY KIND, either express or implied. See the License for the
 specific language governing permissions and limitations under the License.
 """
 import json
-from pathlib import Path
 from hashlib import md5
+from pathlib import Path
 
 
 class VisibilityReport:
@@ -22,17 +22,17 @@ class VisibilityReport:
         self.path = Path(path)
         self.index = {}
 
-        self.path.joinpath('reports').mkdir(parents=True, exist_ok=True)
+        self.path.joinpath("reports").mkdir(parents=True, exist_ok=True)
 
     def save(self, report, verbose=False):
         idx = md5()
-        idx.update(report['arn'].encode('utf-8'))
+        idx.update(report["arn"].encode("utf-8"))
         idx = idx.hexdigest()
 
-        self.index[idx] = report['arn']
+        self.index[idx] = report["arn"]
 
         report = json.dumps(report, indent=4)
-        with self.path.joinpath('reports', f'{idx}.json').open('w') as f:
+        with self.path.joinpath("reports", f"{idx}.json").open("w") as f:
             f.write(report)
         if verbose:
             print(report)
@@ -40,5 +40,5 @@ class VisibilityReport:
         self.save_index()
 
     def save_index(self):
-        with self.path.joinpath('index.json').open('w') as f:
+        with self.path.joinpath("index.json").open("w") as f:
             f.write(json.dumps(self.index, indent=4))
